<?php

/* GRRF.
 * @package Logic
 * @author  francismararaujo
 */

class GRRF{

    CONST ALFANUMERICOS = '/[^a-zA-Z0-9]/';
    CONST ESTRUTURALEGAL = 'ESTRUTURALEGAL';
    CONST ESTRUTURAGERENCIAL = 'ESTRUTURAGERENCIAL';

    private $_formulario;
    private $_nrOrg;
    private $_nrOrgPadrao;
    private $_mesCompetencia;
    private $_dtInicio;
    private $_dtFim;
    private $_dtAux;
    private $_movimentacao;
    private $_estruturacao;
    private $_tpMovTransfM;
    private $_hierarquiaOrg;
    private $_registro;
    private $_registro10;
    private $_registro40;
    private $_grrfMagnetico;
    private $_gfipMagneticoTrab;
    private $_dadoAlterado = array(array());
    private $_dadoVinculo = array();
    private $_dadoMesAnteriorRescisao = array();
    private $_dadoMesRescisao = array();
    private $_dadoAvisoPrevioIndenizado = array();
    private $_dadoSaldoFinsRescisorios = array();
    private $_dadoPensaoJuridica = array();
    private $_nrInscricao;
    private $_nrInscricaoTomador;
    private $_nrTpInscricao;
    private $_nrTpInscricaoTomador;
    private $_codMovimentacao;
    private $_codSaque;
    private $_pessoa;
    private $_sitFuncional;
    private $_vinculoEmpreg;
    private $_ocupacao;
    private $_cbo;
    private $_altSitFuncional;
    private $_alteracaoSalario;
    private $_tpDemissao;
    private $_itemCalculo;
    private $_assocEvento;
    private $_escalaTrabalho;
    private $_evento;
    private $_itemGrupo;
    private $_listaCalculoFolha;
    private $_contaCorrenteParceiro;
    private $_dependentes;

    /* Construtor.
     * @param integer             $nrOrg          Numero da Organizacao.
     * @param integer             $nrOrgPadrao    Numero da Organizacao Padrao.
     * @param TkDateTime          $mesCompetencia Mes de competencia.
     * @param FpagrrfmagnetEntity $grrfMagnetico  Instancia de FpagrrfmagnetEntity.
     * @param string              $nrRecolhimento Numero de recolhimento da GRRF.
     * @param boolean             $competencia13  Identificador de geracao da competencia 13.
     * @author francismararaujo
     */

    public function __construct($nrOrg, $nrOrgPadrao, TkDateTime $mesCompetencia, FpagrrfmagnetEntity $grrfMagnetico,
                                $formulario, $competencia13, FpaGrpitemEntity $itensGrupo, $listaNrCalculoFolha){

        $this->_nrOrg = $nrOrg;
        $this->_nrOrgPadrao = $nrOrgPadrao;
        $this->_mesCompetencia = $mesCompetencia;
        $this->_dtInicio = new TkDateTime($this->_mesCompetencia);
        $this->_dtFim = new TkDateTime($this->_mesCompetencia);
        $this->_dtFim->addMonth(1)->subDay(1);
        $this->_dtAux = new TkDateTime();
        $this->_pessoa = new GpepessoaEntity(null, $this->_nrOrg, $this->_mesCompetencia);
        $this->_sitFuncional = new GpesitufuncmEntity();
        $this->_vinculoEmpreg = new GpevinculoempregEntity();
        $this->_dependentes = new FpadepvinculoEntity(null, $this->_nrOrg, $this->_nrOrgPadrao );
        $this->_ocupacao = new GpeOcupacaomEntity(null, $this->_nrOrg, $this->_mesCompetencia);
        $this->_cbo = new GpeCboEntity();
        $this->_altSitFuncional = new GpealtesitufuncEntity(null, $this->_nrOrgPadrao, $this->_nrOrg);
        $this->_alteracaoSalario = new GpealtesalarioEntity(null, $this->_nrOrg);
        $this->_tpDemissao = new FpaTpdemissaoEntity(null, $this->_nrOrgPadrao, $this->_nrOrg);
        $this->_tpMovTransfM = new GpetpmovtransfmEntity(null, $this->_nrOrgPadrao, $this->_nrOrg, $this->_mesCompetencia);
        $this->_listaCalculoFolha = $listaNrCalculoFolha;
        $this->_itemCalculo = new FpaitecalcfolhaEntity();
        $this->_assocEvento = new FpaassoceventoEntity(null, $this->_nrOrg);
        $this->_evento = new FpaeventomEntity(null, $this->_nrOrg, $this->_nrOrgPadrao, $this->_mesCompetencia);
        $this->_itemGrupo = $itensGrupo;
        $this->_hierarquiaOrg = new HierarquiaorgEntity();
        $this->_estruturacao = new Estruturacao($this->_nrOrg, $this->_nrOrgPadrao, $this->_mesCompetencia);
        $this->_grrfMagnetico = $grrfMagnetico;
        $this->_gfipMagneticoTrab = new FpagfipmagnetEntity();
        $this->_escalaTrabalho = new GpeEscalatrabmEntity();
        $this->_contaCorrenteParceiro = new ContcorrparcEntity(null, $this->_nrOrgPadrao, $this->_nrOrg);
        $this->_registro10 = new Registro10GRRF();
        $this->_registro40 = new Registro40GRRF();
        $this->_formulario = $formulario;
        $this->_inicializaVariaveis($formulario, $competencia13); //!!!!!!!!!!!!!!!!

    }

    private function _inicializaVariaveis($formulario, $competencia13){
        try {
            $this->_estruturacao->carregaHierarquias($formulario->getNrhierarqorg()); //!!!!!!!!!!!!!!!!
        } catch(\Exception $e){
            tk_warning('A Hierarquia selecionada não existe para o(s) vínculo(s) selecionado(s)');
            //throw new Exception ($e->getMessage());
        }
        try{
            $this->_estruturacao->carregaHierarquiasTomador($formulario->getNrhierartomador());
        } catch(\Exception $e){
            tk_warning('A Hierarquia Tomador selecionada não existe para o(s) vínculo(s) selecionado(s)');
            //throw new Exception ($e->getMessage());
        }
        $this->_estruturacao->carregaTipoHierarquia($formulario->getNrhierarqorg());
        $this->_estruturacao->carregaTipoHierarquiaTomador($formulario->getNrhierartomador());
        $this->_registro10->setCodigoRecolhimento($formulario->getNrrecolhimento());
        $this->_registro10->setCodCentralizadorFGTS($formulario->getIdcentralfgts());
        $this->_registro10->setCNPJCentralizador($formulario->getNrinsccentraliz());
        $this->_registro40->setCodigoRecolhimento($formulario->getNrrecolhimento());
        $this->_registro40->setDtHomologacao($formulario->getDthomologacao());
        $this->_registro40->setCompetencia($this->_mesCompetencia);
        $this->_registro40->setCompetencia13($competencia13);
        $this->_registro40->setFGTSMesAnterior($formulario->getFgtsmesanterior());

    }

    /* Cria os registros GRRF e armazena na base (10,12,13,14,20,21,30,32,50,51).
     * @param GpevinculomEntity    $vinculo           Instancia de GpevinculomEntity.
     * @param TipohierarqorgEntity $tipoHierarquia    Instancia de TipohierarqorgEntity.
     * @param string               $tpInscHierarq     Tipo de Inscricao da Hierarquia.
     * @param array                $hierarquias       Lista de hierarquias.
     * @param TipohierarqorgEntity $tipoHierarquiaTom Instancia de TipohierarqorgEntity (tomador).
     * @param string               $tpInscHierarqTom  Tipo de Inscricao da Hierarquia (tomador).
     * @param array                $hierarquiasTom    Lista de hierarquias (tomador).
     * @return void
     * @author francismararaujo
     */

    public function gerarGRRF(GpevinculomEntity $vinculo, $tpInscHierarq, $tpInscHierarqTom){

        $this->_calculaBasesGRRF($vinculo->getNrvinculom());

        $estruturaResp = Gpemovimentacao::getMovimentacao($this->_nrOrg, \FPA::getTipoEstruturaLegalOrg(),
            $vinculo->getNrvinculom());

        if ($estruturaResp) {
            if ($tpInscHierarq === RegistroGRRF::CNPJ) {
                $this->_nrInscricao = preg_replace(
                    self::ALFANUMERICOS,
                    '',
                    $estruturaResp->getEstrutura()->getHistorico()->getCdcnpjestrut()
                );
                $this->_nrTpInscricao = RegistroGRRF::CNPJ;
            } elseif ($tpInscHierarq === RegistroGRRF::CEI) {
                $this->_nrInscricao = preg_replace(
                    self::ALFANUMERICOS, '',
                    $estruturaResp->getEstrutura()->getHistorico()->getCdceiestrut()
                );
                $this->_nrTpInscricao = RegistroGRRF::CEI;
            }

            $this->_preparaRegistro10($estruturaResp->getEstrutura(), $vinculo->getNrvinculom());
            $ocupacao = $this->_ocupacao->retornaOcupacao($vinculo->historico->getNrcargo());

            if ($tpInscHierarqTom) {

                $movimentacaoGeren = Gpemovimentacao::getMovimentacao($this->_nrOrg, \FPA::getTipoEstruturaGerencialOrg(),
                    $vinculo->getNrvinculom());

                if($movimentacaoGeren) {

                    $estruturaTomador = $movimentacaoGeren->getEstrutura()->getEstruturaSuperior();

                    if($estruturaTomador){
                        $this->_preparaRegistro40($vinculo, $ocupacao, $estruturaTomador);
                    }

                }

            }else{
                $this->_preparaRegistro40($vinculo, $ocupacao, $estruturaResp);
            }

        }

    }

    private function _calculaBasesGRRF($nrVinculo){

//        carregar todos os itens de calculo.
        foreach ($this->_listaCalculoFolha as $nrCalculo) {

            $this->_dadoVinculo = array();
            $this->_dadoMesAnteriorRescisao = array();
            $this->_dadoMesRescisao = array();
            $this->_dadoAvisoPrevioIndenizado = array();
            $this->_dadoSaldoFinsRescisorios = array();
            $this->_dadoPensaoJuridica = array();
            $this->_itemCalculo->retornaItensPorVinculo($this->_nrOrg, $nrVinculo, $nrCalculo);

//            $this->_calculaSalarioFamilia();
//            $this->_calculaSalarioMaternidade();
//            $this->_calculaRemuneracaoSem13Salario();
//            $this->_calculaRemuneracao13SalarioMensal();
//            $this->_calculaRemuneracaoContribuicaoPrevidenciaria();
//            $this->_calculaRemuneracao13SalarioCompetenciaMovimento();
//            $this->_calculaRemuneracao13SalarioGPSCompetencia13();
//            $this->_calculaInssMultiplosVinculos();

            $this->_mesAnteriorRescisao();
            $this->_mesRescisao();
            $this->_avisoPrevioIndenizado();
            $this->_SaldoFinsRescisorios();
            $this->_pensaoJuridica();

        }
    }

    /* Prepara para a geracao do Registro 00.
     * @param array                $hierarquias    Lista de Hierarquias.
     * @param string               $tpInscHierarq  Tipo de Inscricao da Hierarquia.
     * @param TipohierarqorgEntity $tipoHierarquia Instancia de TipohierarqorgEntity.
     * @param integer              $nrEstruturaMov Numero da estrutura.
     * @return void
     * @author francismararaujo - 22/02/2013
     */

    private function _preparaRegistro10($estrutura, $nrVinculo){

        $posicao = $this->_grrfMagnetico->procuraRegistroLista(
            $this->_nrInscricao, "0", Registro10GRRF::REGISTRO_10
        );

        if ($posicao === false) {

            $endereco = $this->_estruturacao->determinaEnderecoEstrutura($estrutura);
            $this->_registro10->setTpInscricao($this->_nrTpInscricao);
            $this->_registro10->setNrInscricao($this->_nrInscricao);
            //monta a linha registro 10.
            $this->_registro10->geraRegistro10($estrutura, $endereco);

            //insere novo registro tipo 10 (base). Os campos nulos sao referentes ao tomador.
            $this->_grrfMagnetico->insereRegistroLista(
                $this->_nrOrg, $this->_mesCompetencia, Registro10GRRF::REGISTRO_10, $this->_nrTpInscricao,
                $this->_nrInscricao, $this->_registro10->getLinhaRegistro(),$this->_formulario->getFgtsmesanterior()
            );

            //limpa o registro 10.
            $this->_registro10->setLinhaRegistro();

        } else {
            //
        }

//        $this->_consolidaDadosGRRF(Registro10GRRF::REGISTRO_10, $this->_nrInscricao, 0);

    }

    /* Prepara para a geracao do Registro 40.
     * @param GpevinculomEntity     $vinculo      Instancia de GpevinculomEntity.
     * @param GpemovimentacaoEntity $movimentacao Instancia de GpemovimentacaoEntity.
     * @param GpeOcupacaomEntity    $ocupacao     Instancia de GpeOcupacaomEntity.
     * @param EstruturamEntity      $estrutura    Instancia de EstruturamEntity.
     * @return void
     * @author francismararaujo - 26/02/2013
     */

    private function _preparaRegistro40(GpevinculomEntity $vinculo, $ocupacao, EstruturamEntity $estrutura){

//        tipo de demissao
        if($vinculo->getNrtpdemissao()){

            $objTpDemissao = $this->_tpDemissao->procuraTipoDemissao($vinculo->getNrtpdemissao());
            $this->_codMovimentacao = $objTpDemissao->getCodfgts();
            $this->_codSaque = $objTpDemissao->getCodsaque();

        }else{
            throw new Exception('Tipo de demissao nao parametrizado para o vinculo '.$vinculo->getNrvinculom());
        }

//        verifica se o codigo de movimentação do vínculo é dos tipos listados abaixo. Se for ele não gera o registro 40
        $codigomovimentacao = array('I1','I2','I3','I4','L');
        if (array_search($this->_codMovimentacao, $codigomovimentacao) !== false) {

//            dependentes
            $this->_dependentes->carregaDependenciasPorVinculo($vinculo->getNrvinculom());
            $dependentes = $this->_dependentes->getItems();

            //        //movimentacao
            //        if($movimentacao->getNrtpmovtransfm()){
            //             $tptransferencia = $movimentacao->getNrtpmovtransfm();
            //        }else{
            //            tk_warning('Tipo de transferencia não parametrizado no movimento do vinculo.');
            //        }

            //        $tpMovTransf = $this->_tpMovTransfM->retornaTpMovTransf($tptransferencia);
            //        if (is_object($tpMovTransf) === true) {
            //            $codFGTS = $tpMovTransf->historico->getCodfgts();
            //            $codsaque = $tpMovTransf->historico->getCodsaque();
            //            if (empty($codFGTS) !== true) {
            //                $this->_codMovimentacao = $codFGTS;
            //            }
            //            if (empty($codsaque) !== true) {
            //                $this->_codSaque = $codsaque;
            //            }
            //        }

//            quantidade de horas trabalhadas semana.
            $nrEscalaTrabalho = $vinculo->historico->getNrescalatrabm();
            $escalaTrabalho = $this->_escalaTrabalho->retornaEscala($nrEscalaTrabalho, $this->_nrOrg);
            if (is_object($escalaTrabalho) === true) {
                $vinculo->escalaSemanal = $escalaTrabalho->historico->getQthrsemesctrabh();
            } else {
                tk_warning('Escala Semanal nao parametrizado.');
            }

//            determina ocorrencia.
            if ($vinculo->historico->getIdmultvinc() !== GpevinculohEntity::IDMULTVINC_UNICO) {
                $this->_estruturacao->determinaAreaRisco($vinculo, $estrutura);
                $areaRisco = $this->_estruturacao->getAreaRisco();
                if ($vinculo->historico->getIdmultvinc() === GpevinculohEntity::IDMULTVINC_PRIMARIO) {
                    $vinculo->ocorrencia = $areaRisco->getCdocorfgtsunico();
                } elseif ($vinculo->historico->getIdmultvinc() === GpevinculohEntity::IDMULTVINC_SECUNDARIO) {
                    $vinculo->ocorrencia = $areaRisco->getCdocorfgtsmult();
                }
            } else {
                $vinculo->ocorrencia = null;
            }

//            @todo Verificar codigo CBO.
            if (is_object($ocupacao) === true){
                $cbo = $this->_cbo->retornaCbo($ocupacao->historico->getNrcbo());
                $vinculo->cbo = $cbo->getCdrais();
            } else {
                tk_warning('Nao parametrizado cargo para o vinculo '.$vinculo->getNrvinculom());
                $vinculo->cbo = '';
            }

//            verifica Categoria Trabalhador em situação funcional, se não encontrar pega no vinculoempreg.
            $situacaoFuncional = $this->_sitFuncional->retornaSituacaoFuncional(
                $this->_nrOrgPadrao, $this->_nrOrg, $vinculo->historico->getNrsitufuncm()
            );

            $nrCategoriaTrabalhador = $situacaoFuncional->historico->getCodcategtrab();
            if (empty($nrCategoriaTrabalhador) === true) {
                $vinculoEmpreg = $this->_vinculoEmpreg->retornaVinculoEmpregaticio($vinculo->getNrvinculoempreg());
                if (is_object($vinculoEmpreg) === true) {
                    $nrCategoriaTrabalhador = $vinculoEmpreg->getCodcategtrab();
                }
            }

            $pessoa = $this->_pessoa->retornaPessoaAtual($vinculo->getNrpessoa());
            $contaCorrentePessoa = $this->_contaCorrenteParceiro->retornaContaCorrentePorParceiro($pessoa->getNrparcnegocio());
            if($contaCorrentePessoa){
                $this->_registro40->setBanco($contaCorrentePessoa->getCdbanco());
                $this->_registro40->setAgencia($contaCorrentePessoa->getCdagencia());
                $this->_registro40->setContaCorrente($contaCorrentePessoa->getCdcontcorr());
            }else{
//                @todo - definido assim pois pode passar mais de uma vez.
                $this->_registro40->setBanco(null);
                $this->_registro40->setAgencia(null);
                $this->_registro40->setContaCorrente(null);
                tk_warning('Parceiro de negocio '.$pessoa->getNrparcnegocio().' foi gerado sem conta corrente.');
            }

//            $nrModalidade = $vinculo->historico->getNrtpmodalidsal();
//            pegar na situacao funcional Codfgts e CodfgtsRet
            $this->_registro40->setNrInscricao($this->_nrInscricao);
            $this->_registro40->setTpInscricao($this->_nrTpInscricao);
            $this->_registro40->setNrInscricaoTomador($this->_nrInscricaoTomador);
            $this->_registro40->setTpInscricaoTomador($this->_nrTpInscricaoTomador);
            $this->_registro40->setCodMovimentacao($this->_codMovimentacao);
            $this->_registro40->setCodSaque($this->_codSaque);
            $this->_registro40->setEscalaSemanal($vinculo->escalaSemanal);
            $this->_registro40->setNrCategoria($nrCategoriaTrabalhador);
            $this->_registro40->setTipoDependente($dependentes);

//            registro 40.
            $this->_registro40->geraRegistro40($pessoa, $vinculo, $this->_dadoAvisoPrevioIndenizado, $this->_dadoMesAnteriorRescisao, $this->_dadoMesRescisao, $this->_dadoPensaoJuridica, $this->_dadoSaldoFinsRescisorios);

//            PisPasep.
            $nrPisPasepCi = $pessoa->historico->getNrpispaseppes();

//            persiste registro linha 40.
            $this->_grrfMagnetico->persisteRegistro($this->_nrOrg, $this->_mesCompetencia, Registro40GRRF::REGISTRO_40,
                $this->_nrTpInscricao, $this->_nrInscricao, $this->_registro40->getLinhaRegistro(),
                $vinculo->getNrvinculom(), $vinculo->getDtadmissaovinc(), $nrPisPasepCi, $nrCategoriaTrabalhador,
                $this->_formulario->getFgtsmesanterior());

//            limpa o registro 40.
            $this->_registro40->setLinhaRegistro();

        } else {
            tk_message("Cód. FGTS do Tipo de Demissão do vínculo ".$vinculo->getNrvinculom()." não entra para GRRF.", null, 15000);            
        }

    }

    private function _calculaValorItemGrupo($referencia){
        $valor = $this->_itemGrupo->calculaValorItemGrupoIncidencia($this->_mesCompetencia, $this->_itemCalculo,
            $this->_evento, $referencia);
        return $valor;
    }

//    private function _calculaSalarioFamilia(){
//        $valor = $this->_calculaValorItemGrupo(RegistroGRRF::GRRF_SALARIO_FAMILIA);
//        $this->_consolidaDadosVinculo(RegistroGRRF::GRRF_SALARIO_FAMILIA, $valor);
//    }

    private function _mesAnteriorRescisao(){
        $valor = $this->_calculaValorItemGrupo(RegistroGRRF::GRRF_MES_ANTERIOR_RESCISAO);
        $this->_consolidaDadosMesAnteriorRescisao(RegistroGRRF::GRRF_MES_ANTERIOR_RESCISAO, $valor);
    }

    private function _mesRescisao(){
        $valor = $this->_calculaValorItemGrupo(RegistroGRRF::GRRF_MES_RESCISAO);
        $this->_consolidaDadosMesRescisao(RegistroGRRF::GRRF_MES_RESCISAO, $valor);
    }

    private function _avisoPrevioIndenizado(){
        $valor = $this->_calculaValorItemGrupo(RegistroGRRF::GRRF_AVISO_PREVIO_INDENIZADO);
        $this->_consolidaDadosAvisoPrevioIndenizado(RegistroGRRF::GRRF_AVISO_PREVIO_INDENIZADO, $valor);
    }

    private function _SaldoFinsRescisorios(){
        $valor = $this->_calculaValorItemGrupo(RegistroGRRF::GRRF_SALDO_FINS_RESCISORIOS);
        $this->_consolidaDadosSaldoFinsRescisorios(RegistroGRRF::GRRF_SALDO_FINS_RESCISORIOS, $valor);
    }

    private function _pensaoJuridica(){
        $valor = $this->_calculaValorItemGrupo(RegistroGRRF::GRRF_PENSAO_JURIDICA);
        $this->_consolidaDadosPensaoJuridica(RegistroGRRF::GRRF_PENSAO_JURIDICA, $valor);
    }

//    private function _calculaSalarioMaternidade(){
//        $valor = $this->_calculaValorItemGrupo(RegistroGRRF::GRRF_SALARIO_MATERNIDADE);
//        $this->_consolidaDadosVinculo(RegistroGRRF::GRRF_SALARIO_MATERNIDADE, $valor);
//    }
//
//    private function _calculaRemuneracaoSem13Salario(){
//        $valor = $this->_calculaValorItemGrupo(RegistroGRRF::GRRF_REM_SEM_13SAL);
//        $this->_consolidaDadosVinculo(RegistroGRRF::GRRF_REM_SEM_13SAL, $valor);
//    }
//
//    private function _calculaRemuneracao13SalarioMensal(){
//        $valor = $this->_calculaValorItemGrupo(RegistroGRRF::GRRF_13SAL_PAGO_MES);
//        $this->_consolidaDadosVinculo(RegistroGRRF::GRRF_13SAL_PAGO_MES, $valor);
//    }
//
//    private function _calculaRemuneracaoContribuicaoPrevidenciaria(){
//        $valor = $this->_calculaValorItemGrupo(RegistroGRRF::GRRF_REM_BASE_GPS);
//        $this->_consolidaDadosVinculo(RegistroGRRF::GRRF_REM_BASE_GPS, $valor);
//    }
//
//    private function _calculaRemuneracao13SalarioCompetenciaMovimento(){
//        $valor = $this->_calculaValorItemGrupo(RegistroGRRF::GRRF_REM_13SAL_MOV);
//        $this->_consolidaDadosVinculo(RegistroGRRF::GRRF_REM_13SAL_MOV, $valor);
//    }
//
//    private function _calculaRemuneracao13SalarioGPSCompetencia13(){
//        $valor = $this->_calculaValorItemGrupo(RegistroGRRF::GRRF_REM_13SAL_GPS);
//        $this->_consolidaDadosVinculo(RegistroGRRF::GRRF_REM_13SAL_GPS, $valor);
//    }
//
//    private function _calculaInssMultiplosVinculos(){
//        $valor = $this->_calculaValorItemGrupo(RegistroGRRF::GRRF_INSS_MULT_VINCULOS);
//        $this->_consolidaDadosVinculo(RegistroGRRF::GRRF_INSS_MULT_VINCULOS, $valor);
//    }
//
//    //@todo - caso haja necessidade de modificar outros registros, modificar o nome do metodos para um mais generico.
//    private function _pesquisaSalarioMaternidadeFamilia($tipoAssociacao) {
//    }


//    private function _consolidaDadosVinculo($referencia, $valor) {
//        $this->_dadoVinculo[$referencia] += $valor;
//    }

    private function _consolidaDadosAvisoPrevioIndenizado($referencia, $valor) {
        $this->_dadoAvisoPrevioIndenizado[$referencia] += $valor;
    }

    private function _consolidaDadosMesAnteriorRescisao($referencia, $valor) {
        $this->_dadoMesAnteriorRescisao[$referencia] += $valor;
    }

    private function _consolidaDadosMesRescisao($referencia, $valor) {
        $this->_dadoMesRescisao[$referencia] += $valor;
    }

    private function _consolidaDadosSaldoFinsRescisorios($referencia, $valor) {
        $this->_dadoSaldoFinsRescisorios[$referencia] += $valor;
    }

    private function _consolidaDadosPensaoJuridica($referencia, $valor) {
        $this->_dadoPensaoJuridica[$referencia] += $valor;
    }


//    private function _consolidaDadosGRRF($tpRegistro, $nrInscricao, $nrInscricaoTomador){
//        $posicao = $tpRegistro.'.'.$nrInscricao.'.'.$nrInscricaoTomador;
//
//        if ($tpRegistro === Registro10GRRF::REGISTRO_10){
//            $this->_consolidaDados($posicao, RegistroGRRF::GRRF_SALARIO_MATERNIDADE,
//                $this->_dadoVinculo[RegistroGRRF::GRRF_SALARIO_MATERNIDADE]);
//        }
//
//        $this->_consolidaDados($posicao, RegistroGRRF::GRRF_SALARIO_FAMILIA,
//            $this->_dadoVinculo[RegistroGRRF::GRRF_SALARIO_FAMILIA]);
//
//    }


//    //@todo - caso haja necessidade de modificar outros registros, modificar o nome do metodos para um mais generico.
//    private function _consolidaDados($posicao, $referencia, $valor) {
//        $this->_dadoAlterado[$posicao][$referencia] += $valor;
//    }


//    //@todo - caso haja necessidade de modificar outros registros, modificar o nome do metodos para um mais generico.
//    public function modificaSalarioMaternidadeFamilia() {
//
//        // Modificar
//        foreach ($this->_dadoAlterado as $posicao => $valor) {
//            // Testa a posicao diferente de 0, pois ao ser declarado o vetor cria esta posicao e a mesma nao eh utilizada.
//            if ($posicao !== 0) {
//                list($tpRegistro, $nrInscricao, $nrInscricaoTom) = explode('.', $posicao);
//
//                $posRegistro = $this->_grrfMagnetico->procuraRegistroLista($nrInscricao, $nrInscricaoTom, $tpRegistro);
//                $registroMag = $this->_grrfMagnetico->getItem($posRegistro);
//
//                // criar metodo generico no FPA Registro para fazer modificacao da linha
//                if ($tpRegistro === Registro10GRRF::REGISTRO_10){
//                    $this->_registro10->alteraDadoRegistro10($registroMag, $valor);
//                }
//            }
//        }
//
//    }


    /* Retrocede os registros da Org. no mes de competencia.
     * @return void
     * @author francismararaujo - 01/03/2013
     */

    public function retroceder(){

        try{

            $this->_grrfMagnetico->retroceder($this->_nrOrg, $this->_mesCompetencia);
            tk_message("Retrocedido", 'success');

        }catch (Exception $e){

            tk_message($e->getMessage(),'warning');

        }

    }


}